import tkinter as tk
from tkinter import ttk
import customtkinter as ctk
from PIL import Image, ImageTk
import requests
from io import BytesIO
import json
import os

class WebifyStyle:
    # Cores modernas tipo site
    COLORS = {
        'primary': '#2563eb',
        'secondary': '#4f46e5',
        'success': '#22c55e',
        'danger': '#ef4444',
        'warning': '#f59e0b',
        'info': '#3b82f6',
        'light': '#f8fafc',
        'dark': '#1e293b',
        'white': '#ffffff',
        'black': '#000000',
        'gray': '#64748b'
    }

    # Temas prontos
    THEMES = {
        'light': {
            'bg': '#ffffff',
            'fg': '#1e293b',
            'accent': '#2563eb',
            'hover': '#3b82f6',
            'border': '#e2e8f0'
        },
        'dark': {
            'bg': '#1e293b',
            'fg': '#f8fafc',
            'accent': '#3b82f6',
            'hover': '#60a5fa',
            'border': '#334155'
        }
    }

    # Fontes modernas
    FONTS = {
        'heading': ('Segoe UI', 24, 'bold'),
        'subheading': ('Segoe UI', 18, 'bold'),
        'body': ('Segoe UI', 12),
        'small': ('Segoe UI', 10),
        'button': ('Segoe UI', 12, 'bold')
    }

class WebifyComponent:
    def __init__(self, master, theme='light'):
        self.master = master
        self.theme = WebifyStyle.THEMES[theme]
        
    def create_card(self, title, content, image_url=None):
        frame = ctk.CTkFrame(
            self.master,
            fg_color=self.theme['bg'],
            corner_radius=10,
            border_width=1,
            border_color=self.theme['border']
        )
        
        if image_url:
            try:
                response = requests.get(image_url)
                img = Image.open(BytesIO(response.content))
                img = img.resize((300, 200), Image.Resampling.LANCZOS)
                photo = ImageTk.PhotoImage(img)
                
                img_label = tk.Label(
                    frame,
                    image=photo,
                    bg=self.theme['bg']
                )
                img_label.image = photo
                img_label.pack(pady=10, padx=10)
            except:
                pass
                
        title_label = ctk.CTkLabel(
            frame,
            text=title,
            font=WebifyStyle.FONTS['subheading'],
            text_color=self.theme['fg']
        )
        title_label.pack(pady=10, padx=20)
        
        content_label = ctk.CTkLabel(
            frame,
            text=content,
            font=WebifyStyle.FONTS['body'],
            text_color=self.theme['fg'],
            wraplength=280
        )
        content_label.pack(pady=10, padx=20)
        
        return frame
        
    def create_button(self, text, command):
        return ctk.CTkButton(
            self.master,
            text=text,
            command=command,
            font=WebifyStyle.FONTS['button'],
            fg_color=self.theme['accent'],
            hover_color=self.theme['hover'],
            corner_radius=8
        )
        
    def create_input(self, placeholder):
        return ctk.CTkEntry(
            self.master,
            placeholder_text=placeholder,
            font=WebifyStyle.FONTS['body'],
            fg_color=self.theme['bg'],
            border_color=self.theme['border'],
            corner_radius=8
        )
        
    def create_navbar(self, title, items):
        navbar = ctk.CTkFrame(
            self.master,
            fg_color=self.theme['accent'],
            corner_radius=0,
            height=60
        )
        
        title_label = ctk.CTkLabel(
            navbar,
            text=title,
            font=WebifyStyle.FONTS['heading'],
            text_color='white'
        )
        title_label.pack(side='left', padx=20)
        
        for item in items:
            btn = ctk.CTkButton(
                navbar,
                text=item,
                font=WebifyStyle.FONTS['button'],
                fg_color='transparent',
                hover_color=self.theme['hover'],
                corner_radius=8
            )
            btn.pack(side='left', padx=10)
            
        return navbar

class WebifyApp:
    def __init__(self, title='WebifyApp', theme='light'):
        self.root = tk.Tk()
        self.root.title(title)
        self.root.geometry('1200x800')
        
        # Configura tema
        self.theme = theme
        self.style = WebifyStyle.THEMES[theme]
        self.root.configure(bg=self.style['bg'])
        
        # Componentes
        self.components = WebifyComponent(self.root, theme)
        
        # Layout principal
        self.main_frame = ctk.CTkFrame(
            self.root,
            fg_color=self.style['bg'],
            corner_radius=0
        )
        self.main_frame.pack(fill='both', expand=True)
        
    def add_navbar(self, title, items):
        navbar = self.components.create_navbar(title, items)
        navbar.pack(fill='x')
        
    def add_hero(self, title, subtitle, image_url=None):
        hero_frame = ctk.CTkFrame(
            self.main_frame,
            fg_color=self.style['accent'],
            corner_radius=0,
            height=400
        )
        hero_frame.pack(fill='x', pady=0)
        
        text_frame = ctk.CTkFrame(
            hero_frame,
            fg_color='transparent'
        )
        text_frame.place(relx=0.5, rely=0.5, anchor='center')
        
        title_label = ctk.CTkLabel(
            text_frame,
            text=title,
            font=('Segoe UI', 48, 'bold'),
            text_color='white'
        )
        title_label.pack()
        
        subtitle_label = ctk.CTkLabel(
            text_frame,
            text=subtitle,
            font=('Segoe UI', 24),
            text_color='white'
        )
        subtitle_label.pack(pady=20)
        
    def add_cards_section(self, cards):
        cards_frame = ctk.CTkFrame(
            self.main_frame,
            fg_color=self.style['bg']
        )
        cards_frame.pack(fill='x', pady=40, padx=40)
        
        # Grid de cards
        row = 0
        col = 0
        for card in cards:
            card_widget = self.components.create_card(
                card['title'],
                card['content'],
                card.get('image')
            )
            card_widget.grid(row=row, column=col, padx=10, pady=10)
            
            col += 1
            if col > 2:  # 3 cards por linha
                col = 0
                row += 1
                
    def run(self):
        self.root.mainloop()
